@@ -11,8 +11,8 @@
 #################################################################################
 
 INSTALLER_NAME="Rootkit Hunter installer"
-INSTALLER_VERSION="1.1.7"
-INSTALLER_COPYRIGHT="Copyright 2003-2004, Michael Boelen"
+INSTALLER_VERSION="1.2.4"
+INSTALLER_COPYRIGHT="Copyright 2003-2005, Michael Boelen"
 INSTALLER_LICENSE="
 Rootkit Hunter comes with ABSOLUTELY NO WARRANTY. This is free
 software, and you are welcome to redistribute it under the terms
@@ -81,7 +81,7 @@ done
 #################################################################################
 
 if [ $SHOWUSAGE -eq 1 ]; then
-  echo "${INSTALLER_NAME} ${INSTALL_VERSION}"
+  echo "${INSTALLER_NAME}"
   echo "${INSTALL_LICENSE}"
   echo "Usage: $0 <parameters>"
   echo ""
@@ -98,11 +98,10 @@ fi
 
 #################################################################################
 #
-# Show help / version
+# Installation & configuration
 #
 #################################################################################
 
-
 # Install files
 
 # Prefix: <INSTALLDIR>/lib/rkhunter
@@ -141,6 +140,7 @@ ${INSTALLDIR}/lib/rkhunter/docs
 ${INSTALLDIR}/lib/rkhunter/scripts
 ${INSTALLDIR}/lib/rkhunter/tmp
 /usr/local/etc
+/usr/local/bin
 "
 
 CHECKDIR="/usr/local"
@@ -323,13 +323,37 @@ case $1 in
         t18="Leia a documentação em /usr/local/rkhunter/docs para maiores informações. Digite 'rkhunter' para executar o rootkit"
         t19="Falha na Instalação"
         ;;
+
+	# Turkish
+	tr)
+	t1="inceleniyor "
+	t2="Fatal error: "
+	t2b="mevcut degil"
+	t3="Dosya yukleme araci kontrol ediliyor..."
+	t4="Hata"
+	t5="Fatal error: 'wget' veya 'fetch' araclarindan biri bulunamadi"
+	t6="Kurulum dizinleri kontrol ediliyor..."
+	t7="OK. (Kullaniliyor "
+	t8="- inceleniyor "
+	t9="Mevcut"
+	t10="Olusturuldu"
+	t11="Sistem ayarlari kontrol ediliyor..."
+	t12="Basarisiz"
+	t13="Bulunamadi. Lutfen Perl icin sembolink baglanti olusturun."
+	t14="Dosyalar kuruluyor..."
+	t15="Kuruluyor "
+	t16="Basarisiz (bulunamadi "
+	t17="Kurulum hazir."
+	t18="Daha fazla bilgi icin ${INSTALLDIR}/lib/rkhunter/docs . Sistemde Rootkit taramasi yapmak icin 'rkhunter' yazin"
+	t19="Kurulum basarisiz"
+	;;
 esac
 }
 
 if [ -f ~/.rkhunterlng ]
-then
-   lng=`cat ~/.rkhunterlng`
-     case $lng in
+  then
+    lng=`cat ~/.rkhunterlng`
+    case $lng in
         "en") rep="ok";;
         "fr") rep="ok";;
 	"nl") rep="ok";;
@@ -338,15 +362,15 @@ then
 	*) echo "Language not supported"
               rm -f ~/.rkhunterlng
               exit 1 ;;
-     esac
-else
-     lng="en"
+    esac
+  else
+    lng="en"
 fi     
 
 #     rep="nok"
 #     while [ "$rep" = "nok" ]
 #     do
-#     	echo $N "Language file not detected, which language do you want to use (de/en/fr/nl/se/sp/ptbr) ?"
+#     	echo $N "Language file not detected, which language do you want to use (de/en/fr/nl/se/sp/ptbr/tr) ?"
 #     	read lng
 #             case $lng in
 #	            "de") rep="ok";;
@@ -356,6 +380,7 @@ fi
 #		    "se") rep="ok";;
 #	            "sp") rep="ok";;   
 #	            "ptbr") rep="ok";;   
+#	            "tr") rep="ok";;   
 #		       *) echo "Language not supported";;
 #	     esac
 #     done
@@ -380,15 +405,15 @@ echo $ECHOOPT "---------------"
 echo "Starting installation/update"
 echo ""
 
-echo $N "Checking UID... "
-
-if [ `id -u` = "0" ]
-  then
-    echo "OK"
-  else
-    echo "Sorry, you have to be 'root'. Please su(do) and try again"
-    exit 1
-fi
+# Temporarily disabled
+#echo $N "Checking UID... "
+#if [ `id -u` = "0" ]
+#  then
+#    echo "OK"
+#  else
+#    echo "Sorry, you have to be 'root'. Please su(do) and try again"
+#    exit 1
+#fi
 
 echo $N "$t1 ${CHECKDIR}..."
 if [ -d ${CHECKDIR} ]
@@ -412,7 +437,6 @@ if [ "${SEARCH}" = "" ]
 	    then
 	      echo $E "${t4}"
 	      echo "$t5"
-	      #exit 1
 	    else
     	      RETRTOOL=${SEARCH}
 	  fi
@@ -464,10 +488,11 @@ for I in ${INSTALLFILES}; do
   NEWFILE=`echo ${I} | cut -d ':' -f3`
   DESCRIPTION=`echo ${I} | cut -d ':' -f4 | tr -s '%%' ' '`
 
-  echo $N "$t15 ${DESCRIPTION}... "
+  echo $N "$t15${DESCRIPTION}... "
 
       #error redirection in .rkhunter it's just for a clear display if user run not as root
-      cp -f ${INSTALLPREFIX}${CURFILE} "${INSTALLDIR}/lib/rkhunter${NEWFILE}" 2> ~/.rkhunter.log
+      cp -f ${INSTALLPREFIX}${CURFILE} "${INSTALLDIR}/lib/rkhunter${NEWFILE}"
+      # Redirect logging to logfile: 2> ./rkhunter.log
       if [ $? -eq 0 ]
         then
 	  echo $E "OK"
@@ -487,14 +512,15 @@ for I in ${INSTALLFILES2}; do
   NEWFILE=`echo ${I} | cut -d ':' -f3`
   DESCRIPTION=`echo ${I} | cut -d ':' -f4 | tr -s '%%' ' '`
 
-  echo $N "$t15 ${DESCRIPTION}... "
+  echo $N "$t15${DESCRIPTION}... "
   # Does the file already exists and are we using the no-overwrite mode?
   if [ -f ${NEWFILE} -a ${INSTALLTYPE} = "nooverwrite" ]
     then
       echo "Skipped (no overwrite)"
     else
       #error redirection in .rkhunter it's just for a clear display if user run not as root
-      cp -f ${INSTALLPREFIX}${CURFILE} ${NEWFILE} 2> ~/.rkhunter.log
+      cp -f ${INSTALLPREFIX}${CURFILE} ${NEWFILE}
+      # Redirect logging to logfile: 2> ./rkhunter.log
       if [ $? -eq 0 ]
         then
 	  echo $E "OK"
@@ -526,7 +552,7 @@ then
 else
 	echo ""
 	echo $E "$t19"
-	echo "Check ~/.rkhunter.log"
+	echo "Check ./.rkhunter.log"
 fi
 
 # The End
